@@ -4,8 +4,15 @@ import typer
 
 from globus_automate_client import __version__
 from globus_automate_client.cli import actions, flows, queues
+from globus_automate_client.token_management import CONFIG_PATH
 
-app = typer.Typer(help="Globus Automate CLI")
+help = f"""
+CLI for Globus Automate
+
+By default, this CLI keeps all its config and cached tokens in {CONFIG_PATH}
+"""
+
+app = typer.Typer(help=help, short_help="Globus Automate CLI")
 app.add_typer(actions.app, name="action")
 app.add_typer(flows.app, name="flow")
 app.add_typer(queues.app, name="queue")
